@@ -14,6 +14,9 @@ from .euler import Euler
 from .euler_heun import EulerHeun
 from .heun import Heun
 from .implicit_euler import ImplicitEuler
+from .kencarp3 import KenCarp3
+from .kencarp4 import KenCarp4
+from .kencarp5 import KenCarp5
 from .kvaerno3 import Kvaerno3
 from .kvaerno4 import Kvaerno4
 from .kvaerno5 import Kvaerno5
@@ -30,6 +33,8 @@ from .runge_kutta import (
     AbstractSDIRK,
     ButcherTableau,
     CalculateJacobian,
+    MultiButcherTableau,
 )
 from .semi_implicit_euler import SemiImplicitEuler
+from .sil3 import Sil3
 from .tsit5 import Tsit5
