@@ -16,7 +16,8 @@ _SolverState = None
 class SemiImplicitEuler(AbstractSolver):
     """Semi-implicit Euler's method.
 
-    Symplectic method. Does not support adaptive step sizing.
+    Symplectic method. Does not support adaptive step sizing. Uses 1st order local
+    linear interpolation for dense/ts output.
     """
 
     term_structure = (AbstractTerm, AbstractTerm)
@@ -25,6 +26,16 @@ class SemiImplicitEuler(AbstractSolver):
     def order(self, terms):
         return 1
 
+    def init(
+        self,
+        terms: Tuple[AbstractTerm, AbstractTerm],
+        t0: Scalar,
+        t1: Scalar,
+        y0: PyTree,
+        args: PyTree,
+    ) -> _SolverState:
+        return None
+
     def step(
         self,
         terms: Tuple[AbstractTerm, AbstractTerm],
@@ -35,7 +46,7 @@ class SemiImplicitEuler(AbstractSolver):
         solver_state: _SolverState,
         made_jump: Bool,
     ) -> Tuple[Tuple[PyTree, PyTree], _ErrorEstimate, DenseInfo, _SolverState, RESULTS]:
-        del made_jump
+        del solver_state, made_jump
 
         term_1, term_2 = terms
         y0_1, y0_2 = y0
